#
# spec file for package python-imageio-ffmpeg
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-imageio-ffmpeg
Version:        0.5.1
Release:        1.2
Summary:        FFMPEG wrapper for Python
License:        BSD-2-Clause
Group:          Development/Languages/Python
URL:            https://github.com/imageio/imageio-ffmpeg
Source:         https://files.pythonhosted.org/packages/source/i/imageio-ffmpeg/imageio-ffmpeg-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.9}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  ffmpeg-4
BuildRequires:  python-rpm-macros
Requires:       ffmpeg-4
BuildArch:      noarch
%python_subpackages

%description
FFMPEG wrapper for working with video files in Python.

%prep
%setup -q -n imageio-ffmpeg-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# github version has real tests, but tests require a network connection
%python_expand $python -c 'import imageio_ffmpeg; print(imageio_ffmpeg.get_ffmpeg_version())';

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/imageio_ffmpeg
%{python_sitelib}/imageio_ffmpeg-%{version}.dist-info

%changelog
* Wed Jun 19 2024 Dirk Müller <dmueller@suse.com>
- update to 0.5.1:
  * Prevent __init__.py from being \deleted
- update to 0.5.0:
  * Replace pkg_resources with importlib.resources
  * Add a null filter to re-enable frame count
* Sat Dec 16 2023 Dirk Müller <dmueller@suse.com>
- update to 0.4.9:
  * detect linux-aarch6 correctly for ffmpeg filenames
  * Add GH Sponsors Link
  * Updated deprecated test approach + minor changes
  * Fix format
  * Enable py311 on ci
  * Check CI pypy
  * Add setuptools dependency
  * correct `fps` parsing
* Thu Aug 17 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Sun Mar 26 2023 Dirk Müller <dmueller@suse.com>
- update to 0.4.8:
  * get_ffmpeg_exe always checks env var
  * Fix pix_format parser to capture formats that have commas
    within strings
  * Avoid warning about invalid escape sequence in regex
* Thu Sep 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- v0.4.6 Latest
  Formal support for Python 3.5 -3.10.
  Automatically find available h264 encoders and choose the best.
  Allow users to specify quality=None.
  A fix for closing the std stream.
- v0.4.5
  Set daemon attribute instead of using deprecated setDaemon method.
  Optional disabling of prevent_sigint using env var (#60).
  Get rotation metadata (#39).
- v0.4.4
  Support for Aarch64.
  Basic support to include audio when writing videos.
- Version 0.4.3
  Support for Python 3.9.
  File object is closes after use just in case.
- Version 0.4.2
  Use latest version of ffmpeg (4.2.2)
* Thu Apr  9 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 0.4.1
  * The default value for ffmpeg_timeout is now zero, e.g. just wait for ffmpeg.
  * Added bits_per_pixel parameter to read_frames.
  * Official support for Python 3.8.
  * Improved handling of interrupts during reading/writing/closing-down.
  * Allow the ffmpeg_timeout arg in write_frames() to be None.
  * Don't prevent sigint propagation for ffmpeg call in count_frames_and_secs().
* Wed Apr 17 2019 Todd R <toddrme2178@gmail.com>
- Initial version
